@@ -134,7 +134,7 @@ INVALIDPARAMETER_ZONENOTEXISTS = 'InvalidParameter.ZoneNotExists'
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
-# 内部专用TLD，不支持创建。
+# 内部保留域名，不支持创建。
 INVALIDPARAMETERVALUE_RESERVEDDOMAIN = 'InvalidParameterValue.ReservedDomain'
 
 # 超过配额限制。
@@ -170,9 +170,6 @@ RESOURCENOTFOUND_SERVICENOTSUBSCRIBED = 'ResourceNotFound.ServiceNotSubscribed'
 # 资源不可用。
 RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 
-# TLD增值包超额不允许操作。
-RESOURCEUNAVAILABLE_TLDOPERATELIMIT = 'ResourceUnavailable.TldOperateLimit'
-
 # TLD增值包已过期。
 RESOURCEUNAVAILABLE_TLDPACKAGEEXPIRED = 'ResourceUnavailable.TldPackageExpired'
 
@@ -199,3 +196,6 @@ UNSUPPORTEDOPERATION_ACCOUNTNOTBOUND = 'UnsupportedOperation.AccountNotBound'
 
 # 存在绑定的VPC资源。
 UNSUPPORTEDOPERATION_EXISTBOUNDVPC = 'UnsupportedOperation.ExistBoundVpc'
+
+# 接口调用超过限频。
+UNSUPPORTEDOPERATION_FREQUENCYLIMIT = 'UnsupportedOperation.FrequencyLimit'
